<div data-nowplaying-num="0" id="video-now-playing-num"></div>
<div data-randorder="none" id="vid-randorder"></div>
<div data-playback-ended="false" id="video-playback-ended"></div>
<div class="center">
  <video id="video"{% if autoplay %} autoplay{% endif %}{% if preload_video %} preload="auto"{% endif %} controls>
    <source>
    <p>Your browser doesn't support HTML5 video.</p>
  </video>
  <div id="videoplayer"></div>
  <div class="mobile-hide">

    {% if icons %}
      <button data-cmd="prev" id="vid-prev" title="Click to skip to the previous track in the list.">
        <i class="fas fa-step-backward"></i> Previous
      </button>
      <button class="with-icons" data-stat="off" id="vid-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">
        No Repeat<span class="fa-stack"><i class="fas fa-redo fa-stack-1x"></i><i class="fas fa-slash fa-stack-1x"></i></span>
      </button>
      <button class="with-icons" data-stat="off" id="vid-shuffle" title="Click to toggle between a shuffled track order on and off.">
        Shuffle Off<span class="fa-stack"><i class="fas fa-random fa-stack-1x"></i><i class="fas fa-slash fa-stack-1x"></i></span>
      </button>
      <button data-cmd="fwd" id="vid-next" title="Click to skip to the next track in the list.">
        Next <i class="fas fa-step-forward"></i>
      </button>

    {% else %}
      <button data-cmd="prev" id="vid-prev" title="Click to skip to the previous track in the list.">Previous</button>
      <button data-stat="off" id="vid-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">No Repeat</button>
      <button data-stat="off" id="vid-shuffle" title="Click to toggle between a shuffled track order on and off.">Shuffle Off</button>
      <button data-cmd="fwd" id="vid-next" title="Click to skip to the next track in the list.">Next</button>

    {% endif %}
  </div>

  <div class="mobile-show">
    <div>
      <button data-cmd="prev" id="mobile-vid-prev" title="Click to skip to the previous track in the list.">{% if icons %}<i class="fas fa-step-backward"></i> {% endif %}Previous</button>
      <button data-cmd="fwd" id="mobile-vid-next" title="Click to skip to the next track in the list.">Next{% if icons %} <i class="fas fa-step-forward"></i>{% endif %}</button>
    </div>
    <div>
      <button data-stat="off" id="mobile-vid-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">No Repeat{% if icons %}<span class="fa-stack"><i class="fas fa-redo fa-stack-1x"></i><i class="fas fa-slash fa-stack-1x"></i></span>{% endif %}</button>
      <button data-stat="off" id="mobile-vid-shuffle" title="Click to toggle between a shuffled track order on and off.">Shuffle Off{% if icons %}<span class="fa-stack"><i class="fas fa-random fa-stack-1x"></i><i class="fas fa-slash fa-stack-1x"></i></span>{% endif %}</button>
    </div>
  </div>

  <div class="mobile-hide">
    <p id="video-now-playing" title="The status of the current track.">Paused: <span class="bold" id="video-playing-title" title="The title of the current track."></span></p>
  </div>

  <div id="vtv">
    {% if icons %}
      <button class="with-icons" data-stat="off" id="video-theater-view" title='Click this button to toggle "theater view" on the video player.'>Theater View: Off<span class="fa-stack"><i class="fas fa-theater-masks fa-stack-1x"></i><i class="fas fa-slash fa-stack-1x"></i></span></button>
    {% else %}
      <button data-stat="off" id="video-theater-view" title='Click this button to toggle "theater view" on the video player.'>Theater View: Off</button>
    {% endif %}
  </div>
  {% if link_button %}
    <button id="video-time-link" title="Click this button to have a link to this track at the current time put into your clipboard.">Current Time Link{% if icons %} <i class="fas fa-link"></i>{% endif %}</button>
  {% endif %}
</div>
